#!/bin/sh

DRIVER=arcsas

echo "Driver Installation"

MACHINE=`uname -m`
KERNEL=`uname -r`
export PATH=/bin:/sbin:/usr/bin:/usr/sbin
mkdir /tmp/modules
(cd /tmp/modules; tar xvf /tmp/arcsas/modules.tar) 1>/dev/null 2>&1 || { echo "Fail to extract drivers!"; exit 1; }

for ver in /lib/modules/*; do
	kver=`basename $ver`
	mod=`find /lib/modules/$kver/kernel/fs -type f -name *.ko | head -1`
	vermagic=`modinfo -F vermagic $mod 2> /dev/null`
	[ "$vermagic" = "" ] && vermagic=`strings $mod | grep vermagic`
	( echo "$vermagic" | grep "586" -s -q ) && MACHINE=i686
	( echo "$vermagic" | grep "686" -s -q ) && MACHINE=i686
	( echo "$vermagic" | grep "amd64" -s -q ) && MACHINE=x86_64

	if [ -d /lib/modules/${kver} -a -d /tmp/modules/${kver} ]; then
		echo "Updating ${kver}..."
		mkdir -p /lib/modules/${kver}/kernel/drivers/scsi/${DRIVER} &&
		cp /tmp/modules/${kver}/${MACHINE}/${DRIVER}.ko /lib/modules/${kver}/kernel/drivers/scsi/${DRIVER}/ &&
		echo 'arcsas' >> /etc/initramfs-tools/modules
		echo 'blacklist mvsas' >> /etc/modprobe.d/blacklist.local.conf
		/sbin/depmod -a ${kver}

		if [ $? = 1 ]; then
			echo "Postinstall 1 failed! Please reinstall your GNU/Linux system."
			exit
		fi

		update-initramfs -u -k ${kver}

		if [ $? = 1 ]; then
			echo "Postinstall 2 failed! Please reinstall your GNU/Linux system."
			exit
		fi
	fi
done

rm -fr /tmp/modules
sync;sync;sync
echo "Driver Installation Step 2 Completed."
